/*Spengler.cs
 *
 * Main source file for Spengler
 * A 2D Platform Engine using XNA
 *
 * Created 7 February 2007 By Gavin Cox
 *
 * Hirtory of modifications
 * 
 * Mod Tag  | UserID   | Date      | Description
 * ---------|----------|-----------|------------------------------------------------|
 * 09020701 | AMG25    | 09/02/07  | Created a sprite class and altered the engine  |
 *          |          |           | to load via the class                          |
 * ---------|----------|-----------|------------------------------------------------|
 * 
 * Copyright  2007 All Rights Reserved
 */
#region Using Statements
using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Storage;
#endregion

namespace Spengler
{
	/// <summary>
	/// This is the main type for your game
	/// </summary>
	public class Spengler : Microsoft.Xna.Framework.Game
	{
		GraphicsDeviceManager graphics;
		ContentManager content;

		private SpriteBatch spritebatch;
        //09020701
        private Sprite Bill;
        //09020701~

        double elapsed;

		public Spengler()
		{
			graphics = new GraphicsDeviceManager(this);
			content = new ContentManager(Services);

			graphics.PreferredBackBufferWidth = Globals.SCREENWIDTH;
			graphics.PreferredBackBufferHeight = Globals.SCREENHEIGHT;
			this.Window.Title = "Spengler v" + Globals.VERSION.ToString();
		}


		/// <summary>
		/// Allows the game to perform any initialization it needs to before starting to run.
		/// This is where it can query for any required services and load any non-graphic
		/// related content.  Calling base.Initialize will enumerate through any components
		/// and initialize them as well.
		/// </summary>
		protected override void Initialize()
		{
			// TODO: Add your initialization logic here

			base.Initialize();		
		}


		/// <summary>
		/// Load your graphics content.  If loadAllContent is true, you should
		/// load content from both ResourceManagementMode pools.  Otherwise, just
		/// load ResourceManagementMode.Manual content.
		/// </summary>
		/// <param name="loadAllContent">Which type of content to load.</param>
		protected override void LoadGraphicsContent(bool loadAllContent)
		{
			if (loadAllContent)
			{
				//Sprite Batch
				spritebatch = new SpriteBatch(graphics.GraphicsDevice);

				//Bill
                //09020701
                Bill = new Sprite(content, spritebatch, new Vector2((Globals.SCREENWIDTH / 2) - 32, Globals.SCREENHEIGHT - 192), "Graphics\\Bill", 4, 64);
                //09020701~
			}

			// TODO: Load any ResourceManagementMode.Manual content
		}


		/// <summary>
		/// Unload your graphics content.  If unloadAllContent is true, you should
		/// unload content from both ResourceManagementMode pools.  Otherwise, just
		/// unload ResourceManagementMode.Manual content.  Manual content will get
		/// Disposed by the GraphicsDevice during a Reset.
		/// </summary>
		/// <param name="unloadAllContent">Which type of content to unload.</param>
		protected override void UnloadGraphicsContent(bool unloadAllContent)
		{
			if (unloadAllContent == true)
			{
				content.Unload();
			}
		}


		/// <summary>
		/// Allows the game to run logic such as updating the world,
		/// checking for collisions, gathering input and playing audio.
		/// </summary>
		/// <param name="gameTime">Provides a snapshot of timing values.</param>
		protected override void Update(GameTime gameTime)
		{
			// Allows the default game to exit on Xbox 360 and Windows
			if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
				this.Exit();

			// TODO: Add your update logic here
            //09020701
            elapsed += gameTime.ElapsedGameTime.TotalMilliseconds;

            if((elapsed) > 50) // once every four seconds
            {
                if (Keyboard.GetState().IsKeyUp(Keys.Right))
                {
                    Bill.setFrameNo(0);
                }
                if (Keyboard.GetState().IsKeyDown(Keys.Right))
                {
                    Bill.nextFrame();
                    Vector2 v = Bill.getPosition();
                    
                    if (v.X > 1280)
                    {
                        v.X = -64;
                    }
                    
                    Bill.setPosition(new Vector2(v.X+5,v.Y));                   

                    elapsed = 0;
                }
            }
            //09020701~
			base.Update(gameTime);
		}


		/// <summary>
		/// This is called when the game should draw itself.
		/// </summary>
		/// <param name="gameTime">Provides a snapshot of timing values.</param>
		protected override void Draw(GameTime gameTime)
		{
			//Clear Screen
			graphics.GraphicsDevice.Clear(Color.CornflowerBlue);

			//Color Rect for Ground
			Rectangle[] rect = new Rectangle[1];
			rect[0] = new Rectangle(0, Globals.SCREENHEIGHT - 128, Globals.SCREENWIDTH, Globals.SCREENHEIGHT);
			graphics.GraphicsDevice.Clear(ClearOptions.Target, Color.Green, 0.0f, 0, rect);

			//Begin SpriteBatch
			spritebatch.Begin();

			//Bill
            //09020701
            Bill.Draw();
            //09020701~

			//End SpriteBatch
			spritebatch.End();

			base.Draw(gameTime);
		}
	}
}