/*Sprite.cs
 *
 * A Class to handle the attributes 
 * assosiated with a sprite.
 *
 * Created 9 February 2007 By Andrew Grundy
 *
 * Hirtory of modifications
 * Mod Tag  | UserID   | Date      | Description
 * ---------|----------|-----------|------------------------------------------------|
 *          |          |           |                                                |
 * ---------|----------|-----------|------------------------------------------------|
 * 
 * Copyright  2007 All Rights Reserved
 */


using System;
using System.Collections.Generic;
using System.Text;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Content;

namespace Spengler
{
    public class Sprite
    {
        protected Texture2D texture;
        protected Rectangle[] frame;
        protected SpriteBatch spritebatch;
        protected ContentManager content;
        protected Vector2 position;
        protected int currentframe;
        protected int totalframes;

        /*
         * This constructor is for a linier sprite map
         * cont:        XNA ContentManager
         * sbatch:      XNA SpriteBatch from Spengler
         * texfile:     The location of the texture (e.g. Graphics\\Bill)
         * frames:      number of frames
         * framesize:   pixels square (e.g. 64)
         */
        public Sprite(ContentManager cont, SpriteBatch sbatch, Vector2 pos, String texfile, int frames, int framesize)
        {
            content = cont;
            spritebatch = sbatch;
            position = pos;
            texture = content.Load<Texture2D>(texfile);
            frame = new Rectangle[frames];
            for (int i = 0; i < frames; i++)
            {
                frame[i] = new Rectangle( ( i * framesize ), 0, framesize, framesize);
            }
            currentframe = 0;
            totalframes = frames;
        }

        public void setFrameNo(int frameno)
        {
            currentframe = frameno;
        }

        public void nextFrame()
        {
            if (currentframe == (totalframes-1))
            {
                currentframe = 0;
            }
            else
            {
                currentframe++;
            }
        }

        public Vector2 getPosition()
        {
            return position;
        }

        public void setPosition(Vector2 pos)
        {
            position = pos;
        }

        public void Draw()
        {
            //spritebatch.Draw(texture, position, (Rectangle)frame[currentframe] ,Color.White);
			spritebatch.Draw(texture, position, frame[currentframe], Color.White);
        }
    }
}
